yakumo.glance.v2.image

Package yakumo :: Package glance :: Package v2 :: Module image |
[hide private]
[frames] | no frames]

# Module image

source code

Resource class and its manager for images in Image V2 API

Classes | [hide private]
| Resource resource class for images on Image V2 API
| Manager manager class for images on Image V2 API

Variables | [hide private]
| VISIBILITY_MAPPING = ``[``(`True`,` `'``public``'``)``,` `(`False`,` `'``private``'``)``]``
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.glance.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('name', 'name', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('file', 'file', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('disk_format',
        'disk_format',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('container_format',
        'container_format',
      ...